Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2009-11-02 20:25:15 +0300
committerCampbell Barton <ideasman42@gmail.com>2009-11-02 20:25:15 +0300
commit6bfcd5a811e08929505568eb1c9195459149b6fc (patch)
treea8de2dc5d23de126015b8a52c4c3c41b2ce5e8c5 /source/gameengine
parent072a39004eef9f1eb479153888f0bf67b05aa125 (diff)
how embarrassing!
Diffstat (limited to 'source/gameengine')
-rw-r--r--source/gameengine/GamePlayer/common/windows/GPW_KeyboardDevice.cpp18
-rw-r--r--source/gameengine/GamePlayer/common/windows/GPW_KeyboardDevice.h4
2 files changed, 11 insertions, 11 deletions
diff --git a/source/gameengine/GamePlayer/common/windows/GPW_KeyboardDevice.h b/source/gameengine/GamePlayer/common/windows/GPW_KeyboardDevice.h
index cae7488c70d..d8185f01ce9 100644
--- a/source/gameengine/GamePlayer/common/windows/GPW_KeyboardDevice.h
+++ b/source/gameengine/GamePlayer/common/windows/GPW_KeyboardDevice.h
@@ -57,9 +57,9 @@ protected:
void CheckForSeperateLeftRight(WPARAM wParam);
/** Stores the capability of this system to distinguish left and right modifier keys. */
- bool m_seperateLeftRight;
+ bool m_separateLeftRight;
/** Stores the initialization state of the member m_leftRightDistinguishable. */
- bool m_seperateLeftRightInitialized;
+ bool m_separateLeftRightInitialized;
};
#endif //_GPW_KEYBOARDDEVICE_H_
diff --git a/source/gameengine/GamePlayer/common/windows/GPW_KeyboardDevice.cpp b/source/gameengine/GamePlayer/common/windows/GPW_KeyboardDevice.cpp
index 18724783307..0eb418ddfaf 100644
--- a/source/gameengine/GamePlayer/common/windows/GPW_KeyboardDevice.cpp
+++ b/source/gameengine/GamePlayer/common/windows/GPW_KeyboardDevice.cpp
@@ -72,8 +72,8 @@
GPW_KeyboardDevice::GPW_KeyboardDevice(void)
{
- m_seperateLeftRight = false;
- m_seperateLeftRightInitialized = false;
+ m_separateLeftRight = false;
+ m_separateLeftRightInitialized = false;
m_reverseKeyTranslateTable['A' ] = KX_AKEY ;
m_reverseKeyTranslateTable['B' ] = KX_BKEY ;
@@ -222,10 +222,10 @@ void GPW_KeyboardDevice::ConvertModifierKey(WPARAM wParam, bool isDown)
It didn't work all that well on some newer hardware, and worked less
well with the passage of time, so it was fully disabled in ME.
*/
- if (!m_seperateLeftRightInitialized && isDown) {
+ if (!m_separateLeftRightInitialized && isDown) {
CheckForSeperateLeftRight(wParam);
}
- if (m_seperateLeftRight) {
+ if (m_separateLeftRight) {
bool down = HIBYTE(::GetKeyState(VK_LSHIFT)) != 0;
ConvertEvent(VK_LSHIFT, down);
down = HIBYTE(::GetKeyState(VK_RSHIFT)) != 0;
@@ -255,26 +255,26 @@ void GPW_KeyboardDevice::ConvertModifierKey(WPARAM wParam, bool isDown)
void GPW_KeyboardDevice::CheckForSeperateLeftRight(WPARAM wParam)
{
// Check whether this system supports seperate left and right keys
switch (wParam) {
case VK_SHIFT:
- m_seperateLeftRight =
+ m_separateLeftRight =
(HIBYTE(::GetKeyState(VK_LSHIFT)) != 0) ||
(HIBYTE(::GetKeyState(VK_RSHIFT)) != 0) ?
true : false;
break;
case VK_CONTROL:
- m_seperateLeftRight =
+ m_separateLeftRight =
(HIBYTE(::GetKeyState(VK_LCONTROL)) != 0) ||
(HIBYTE(::GetKeyState(VK_RCONTROL)) != 0) ?
true : false;
break;
case VK_MENU:
- m_seperateLeftRight =
+ m_separateLeftRight =
(HIBYTE(::GetKeyState(VK_LMENU)) != 0) ||
(HIBYTE(::GetKeyState(VK_RMENU)) != 0) ?
true : false;
break;
}
- m_seperateLeftRightInitialized = true;
+ m_separateLeftRightInitialized = true;
}
@@ -255,26 +255,26 @@ void GPW_KeyboardDevice::ConvertModifierKey(WPARAM wParam, bool isDown)
void GPW_KeyboardDevice::CheckForSeperateLeftRight(WPARAM wParam)
{
- // Check whether this system supports seperate left and right keys
+ // Check whether this system supports separate left and right keys
switch (wParam) {
case VK_SHIFT: